==> haskell-iproute-1.7.10-13-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-iproute.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 iproute
version:              1.7.10
visibility:           public
id:                   iproute-1.7.10-GL05VGUnca2J6K18yfGnBp
key:                  iproute-1.7.10-GL05VGUnca2J6K18yfGnBp
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
homepage:             http://www.mew.org/~kazu/proj/iproute/
synopsis:             IP Routing Table
description:
    IP Routing Table is a tree of IP ranges
    to search one of them on the longest
    match base. It is a kind of TRIE with one
    way branching removed. Both IPv4 and IPv6
    are supported.

category:             Algorithms, Network
abi:                  3ce75d1c969e8269623e34c1bbccc848
exposed:              True
exposed-modules:
    Data.IP Data.IP.Builder Data.IP.Internal Data.IP.RouteTable
    Data.IP.RouteTable.Internal

hidden-modules:       Data.IP.Addr Data.IP.Mask Data.IP.Op Data.IP.Range
import-dirs:          /usr/lib/ghc-8.10.3/site-local/iproute-1.7.10
library-dirs:         /usr/lib/ghc-8.10.3/site-local/iproute-1.7.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/iproute-1.7.10
hs-libraries:         HSiproute-1.7.10-GL05VGUnca2J6K18yfGnBp
depends:
    appar-0.1.8-KYad8eEAlRI90NAZOjuGzF base-4.14.1.0
    byteorder-1.0.4-6EbuxeSrPBWBwiiH90AHKg bytestring-0.10.12.0
    containers-0.6.2.1 network-3.1.2.1-66iLmEDwBI3LCeEFNs39j4

haddock-interfaces:   /usr/share/doc/haskell-iproute/html/iproute.haddock
haddock-html:         /usr/share/doc/haskell-iproute/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-iproute-1.7.10-16-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-iproute.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 iproute
version:              1.7.10
visibility:           public
id:                   iproute-1.7.10-77XaWgQqOsIGUOYr4XPa5i
key:                  iproute-1.7.10-77XaWgQqOsIGUOYr4XPa5i
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
homepage:             http://www.mew.org/~kazu/proj/iproute/
synopsis:             IP Routing Table
description:
    IP Routing Table is a tree of IP ranges
    to search one of them on the longest
    match base. It is a kind of TRIE with one
    way branching removed. Both IPv4 and IPv6
    are supported.

category:             Algorithms, Network
abi:                  d50ad0e98da5baa59b52d8e5e146172d
exposed:              True
exposed-modules:
    Data.IP Data.IP.Builder Data.IP.Internal Data.IP.RouteTable
    Data.IP.RouteTable.Internal

hidden-modules:       Data.IP.Addr Data.IP.Mask Data.IP.Op Data.IP.Range
import-dirs:          /usr/lib/ghc-8.10.3/site-local/iproute-1.7.10
library-dirs:         /usr/lib/ghc-8.10.3/site-local/iproute-1.7.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/iproute-1.7.10
hs-libraries:         HSiproute-1.7.10-77XaWgQqOsIGUOYr4XPa5i
depends:
    appar-0.1.8-KYad8eEAlRI90NAZOjuGzF base-4.14.1.0
    byteorder-1.0.4-6EbuxeSrPBWBwiiH90AHKg bytestring-0.10.12.0
    containers-0.6.2.1 network-3.1.2.1-9y0VtTYWqqL3JppbGD3fYJ

haddock-interfaces:   /usr/share/doc/haskell-iproute/html/iproute.haddock
haddock-html:         /usr/share/doc/haskell-iproute/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
